@@ -1,8 +1,6 @@
-# coding: utf-8
-
-from __future__ import unicode_literals
 from .. import Provider as DateTimeProvider
 
+
 class Provider(DateTimeProvider):
 
     def day_of_week(self):
